@@ -1,4 +1,6 @@
 /*  xfce4-places-plugin
+ *
+ *  Headers for wrappers to open external applications.
  *
  *  Copyright (c) 2007 Diego Ongaro <ongardie@gmail.com>
  *
@@ -20,38 +22,15 @@
 #ifndef _XFCE_PANEL_PLACES_H
 #define _XFCE_PANEL_PLACES_H
 
-#include <gtk/gtk.h>
-#include <libxfce4panel/xfce-panel-plugin.h>
-
-typedef struct _PlacesData PlacesData;
-#include "cfg.h"
+#include <glib.h>
 
 #define PLUGIN_NAME "places"
 
-struct _PlacesData
-{
-  // plugin
-  XfcePanelPlugin   *plugin;
+void places_load_thunar(const gchar *path);
+void places_load_terminal(const gchar *path);
+void places_load_file(const gchar *path);
+void places_gui_exec(const gchar *cmd);
 
-  // configuration
-  PlacesConfig      *cfg;
-
-  // view
-  GtkWidget         *view_button;
-  GtkWidget         *view_button_box;
-  GtkWidget         *view_button_image;
-  GtkWidget         *view_button_label;
-  GtkWidget         *view_menu;
-  GtkTooltips       *view_tooltips;
-  gulong             view_theme_timeout_id;
-  gboolean           view_just_separated;
-
-  // model
-  gpointer           bookmarks;
-
-};
-
-void places_load_thunar(const gchar*);
 
 #endif
-// vim: ai et tabstop=4
+/* vim: set ai et tabstop=4: */
